import { 
  select, 
  csv, 
  scaleLinear, 
  max, 
  scaleBand, 
  axisLeft,
	axisBottom} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const xValue = d => d.area;
  const yValue = d => d.country;
  const margin = {top: 20, right:40, bottom:30, left:120};
  const innerWidth = width - margin.left - margin.right;
  const innerHeighh = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeighh])
  	.padding(0.2);

  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0, ${innerHeighh})`);
  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  	.attr('y', d => yScale(yValue(d)))
  	.attr('width', 0)
    .attr('height', yScale.bandwidth)
  		.transition().duration(2000)
  			.attr('width', d => xScale(xValue(d)))

};

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.area = +d.area/ 1000000;
  });
	render(data);
});


















